type OnMove = (n: {
    offsetX: number;
    offsetY: number;
    key?: string;
    pageX: number;
    pageY: number;
    startX: number;
    startY: number;
}) => void;
type OnMoveEnd = () => void;
interface DragMethodProps {
    key?: string;
    /**
     * Tracks the movement of the drag and triggers the onMove callback.
     * @callback OnMove
     * @param {object} options - The options object.
     * @param {number} options.offsetX - The X offset of the drag.
     * @param {number} options.offsetY - The Y offset of the drag.
     * @param {number} options.pageX - The X coordinate of the drag.
     * @param {number} options.pageY - The Y coordinate of the drag.
     * @param {number} options.startX - The initial X coordinate of the drag.
     * @param {number} options.startY - The initial Y coordinate of the drag.
     * @param {string} options.key - The key associated with the drag.
     */
    onMove?: OnMove;
    /**
     * Ends the drag event and triggers the onMoveEnd callback.
     * @callback OnMoveEnd
     */
    onMoveEnd?: OnMoveEnd;
}
/**
 * Class for handling drag events in a UI.
 */
export declare class DragMethod {
    private readonly key?;
    private readonly cache;
    private readonly onMouseMove;
    private readonly onMouseUp;
    readonly onMouseDown: any;
    readonly onTouchStart: any;
    onMove?: OnMove;
    onMoveEnd?: OnMoveEnd;
    constructor({ key, onMove, onMoveEnd }?: DragMethodProps);
    private _onMouseMove;
    private clearListener;
    private _onMouseUp;
    private _onMouseDown;
}
export {};
